

set -ex



test -L $PREFIX/lib/libcusparse.so.12.4.1.24
test -L $PREFIX/lib/libcusparse.so.12
test -L $PREFIX/targets/sbsa-linux/lib/libcusparse.so.12
test -f $PREFIX/targets/sbsa-linux/lib/libcusparse.so.12.4.1.24
exit 0
